@@ -7,11 +7,11 @@ from tests.utils import Command
     Command(script='python foo'),
     Command(script='python bar')])
 def test_match(command):
-    assert match(command, None)
+    assert match(command)
 
 
 @pytest.mark.parametrize('command, new_command', [
     (Command('python foo'), 'python foo.py'),
     (Command('python bar'), 'python bar.py')])
 def test_get_new_command(command, new_command):
-    assert get_new_command(command, None) == new_command
+    assert get_new_command(command) == new_command
