@@ -4,9 +4,9 @@ from tests.utils import Command
 
 
 def test_match():
-    assert match(Command('sl'), None)
-    assert not match(Command('ls'), None)
+    assert match(Command('sl'))
+    assert not match(Command('ls'))
 
 
 def test_get_new_command():
-    assert get_new_command(Command('sl'), None) == 'ls'
+    assert get_new_command(Command('sl')) == 'ls'
