@@ -1,14 +1,14 @@
 import re
-from thefuck.utils import replace_argument
+from thefuck.utils import replace_argument, for_app
 
 
-def match(command, settings):
-    return ('composer' in command.script
-            and ('did you mean this?' in command.stderr.lower()
-                 or 'did you mean one of these?' in command.stderr.lower()))
+@for_app('composer')
+def match(command):
+    return (('did you mean this?' in command.stderr.lower()
+             or 'did you mean one of these?' in command.stderr.lower()))
 
 
-def get_new_command(command, settings):
+def get_new_command(command):
     broken_cmd = re.findall(r"Command \"([^']*)\" is not defined", command.stderr)[0]
     new_cmd = re.findall(r'Did you mean this\?[^\n]*\n\s*([^\n]*)', command.stderr)
     if not new_cmd:
