@@ -1,5 +1,7 @@
 import os
 import zipfile
+from thefuck.utils import for_app
+from thefuck.shells import quote
 
 
 def _is_bad_zip(file):
@@ -12,7 +14,7 @@ def _zip_file(command):
     # unzip [-flags] file[.zip] [file(s) ...] [-x file(s) ...]
     #                ^          ^ files to unzip from the archive
     #                archive to unzip
-    for c in command.script.split()[1:]:
+    for c in command.script_parts[1:]:
         if not c.startswith('-'):
             if c.endswith('.zip'):
                 return c
@@ -20,20 +22,25 @@ def _zip_file(command):
                 return '{}.zip'.format(c)
 
 
-def match(command, settings):
-    return (command.script.startswith('unzip')
-            and '-d' not in command.script
+@for_app('unzip')
+def match(command):
+    return ('-d' not in command.script
             and _is_bad_zip(_zip_file(command)))
 
 
-def get_new_command(command, settings):
-    return '{} -d {}'.format(command.script, _zip_file(command)[:-4])
+def get_new_command(command):
+    return '{} -d {}'.format(command.script, quote(_zip_file(command)[:-4]))
 
 
-def side_effect(command, settings):
-    with zipfile.ZipFile(_zip_file(command), 'r') as archive:
+def side_effect(old_cmd, command):
+    with zipfile.ZipFile(_zip_file(old_cmd), 'r') as archive:
         for file in archive.namelist():
-            os.remove(file)
+            try:
+                os.remove(file)
+            except OSError:
+                # does not try to remove directories as we cannot know if they
+                # already existed before
+                pass
 
 
 requires_output = False
