@@ -1,13 +1,14 @@
 from itertools import dropwhile, takewhile, islice
 import re
 import subprocess
-from thefuck.utils import get_closest, sudo_support, replace_argument
+from thefuck.utils import replace_command, for_app
+from thefuck.specific.sudo import sudo_support
 
 
 @sudo_support
-def match(command, settings):
-    return command.script.startswith('docker') \
-           and 'is not a docker command' in command.stderr
+@for_app('docker')
+def match(command):
+    return 'is not a docker command' in command.stderr
 
 
 def get_docker_commands():
@@ -20,8 +21,7 @@ def get_docker_commands():
 
 
 @sudo_support
-def get_new_command(command, settings):
+def get_new_command(command):
     wrong_command = re.findall(
         r"docker: '(\w+)' is not a docker command.", command.stderr)[0]
-    fixed_command = get_closest(wrong_command, get_docker_commands())
-    return replace_argument(command.script, wrong_command, fixed_command)
+    return replace_command(command, wrong_command, get_docker_commands())
